==> thirdparty-service-biz-0.0.8-20171013.114628-1-sources.jar: cn/com/duiba/biz/credits/FengJinApi.java <==
package cn.com.duiba.biz.credits;

import cn.com.duiba.credits.sdk.SignTool;
import cn.com.duiba.dao.AppDAO;
import cn.com.duiba.domain.AppDO;
import cn.com.duiba.notifycenter.domain.NotifyQueueDO;
import cn.com.duiba.order.center.api.dto.CreditsMessage;
import cn.com.duiba.thirdparty.dto.CreditsMessageDto;
import cn.com.duiba.tool.AssembleTool;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.util.Arrays;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Created by xutao on 2017/8/14.
 */
@Service
public class FengJinApi {
    private static Logger log = LoggerFactory.getLogger(FengJinApi.class);

    public static final String UID = "uid";

    @Autowired
    private AppDAO appDAO;

    /**
     * 针对减积分的对象
     * @param creditsMessage
     * @return
     */
    public CreditsMessage getSubCreditsMessage(CreditsMessage creditsMessage) {
        String url = getUrl(creditsMessage.getHttpType(), creditsMessage.getAuthParams(), creditsMessage.getHttpUrl());
        creditsMessage.setHttpUrl(url);
        log.info("appId = {}, url = {}", creditsMessage.getAppId(), creditsMessage.getHttpUrl());
        return creditsMessage;
    }

    private String getUrl(String httpType, Map<String, String> params, String url) {
        if (CreditsMessage.HTTP_POST.equals(httpType)) {
            if(params != null && StringUtils.isNotBlank(params.get("uid"))){
                url = getFengJinPostUrl(url, params);
            }
        } else {
            url = getFengJinGetUrl(url);
        }
        return url;
    }

    /**
     * 针对加积分的对象
     * @param creditsMessageDto
     * @return
     */
    public CreditsMessageDto getAddCreditsMessageDto(CreditsMessageDto creditsMessageDto) {
        String url = getUrl(creditsMessageDto.getHttpType(), creditsMessageDto.getAuthParams(), creditsMessageDto.getHttpUrl());
        creditsMessageDto.setHttpUrl(url);
        log.info("appId = {}, url = {}", creditsMessageDto.getAppId(), creditsMessageDto.getHttpUrl());
        return creditsMessageDto;
    }

    /**
     * 凤金积分商城, 获取通知请求参数
     * @param notifyUrl
     * @param record
     * @return
     */
    public String getRequestNotify(String notifyUrl, NotifyQueueDO record, AppDO appDO){
        Map<String, String> params = new HashMap();
        if(record.getResult() != null){
            params.put("success", String.valueOf(record.getResult()));
        }

        if(StringUtils.isNotEmpty(record.getError4developer())) {
            params.put("errorMessage", record.getError4developer());
        }
        if(StringUtils.isNotEmpty(record.getDeveloperBizId())){
            params.put("bizId",record.getDeveloperBizId());
        }
        params.put("appKey", appDO.getAppKey());
        params.put("appSecret", appDAO.getAppSecret(appDO));
        params.put("timestamp", String.valueOf(Long.valueOf(new Date().getTime())));
        if(StringUtils.isNotEmpty(record.getPartnerUserId())){
            params.put("uid", record.getPartnerUserId());
        }

        params.put("orderNum", record.getDuibaOrderNum());
        String sign = SignTool.sign(params);
        params.remove("appSecret");
        params.put("sign", sign);

        if(StringUtils.isNotBlank(record.getPartnerUserId())){
            if(notifyUrl.endsWith("/")){
                notifyUrl = notifyUrl + record.getPartnerUserId();
            }else{
                notifyUrl = notifyUrl + "/" + record.getPartnerUserId();
            }
        }

        return AssembleTool.assembleUrl(notifyUrl, params);
    }

    /**
     * 凤金积分商城 url handler
     * @param url
     * @return
     */
    private String getFengJinGetUrl(String url){
        try{
            String[] arr = url.split("[?]");
            String newUrl = arr[0];
            if(arr.length < 2){
                return newUrl;
            }

            List<String> paramList = Arrays.asList(arr[1].split("[&]"));
            for(String value : paramList){
                if(StringUtils.isNotBlank(value) && value.trim().startsWith("uid=")){
                    String uid = value.replace("uid=", "");
                    if(StringUtils.isBlank(uid)){
                        break;
                    }
                    if(newUrl.endsWith("/")){
                        newUrl = newUrl + URLDecoder.decode(uid, "utf-8");
                    }else{
                        newUrl = newUrl + "/" + URLDecoder.decode(uid, "utf-8");
                    }
                    break;
                }
            }

            newUrl = newUrl + "?" + arr[1];
            return newUrl;
        }catch (UnsupportedEncodingException e){
            log.error("[AssembleTool-getFengJinGetUrl] URL parsing error, url: " + url,e);
            throw new IllegalStateException("URL parsing error when using utf-8");
        }
    }

    /**
     * 凤金积分商城 url handler
     * @param url
     * @param params
     * @return
     */
    private String getFengJinPostUrl(String url, Map<String, String> params){
        String[] arr = url.split("[?]");
        String newUrl = arr[0];
        if(newUrl.endsWith("/")){
            newUrl = newUrl + params.get(UID);
        }else{
            newUrl = newUrl + "/" + params.get(UID);
        }

        if(arr.length > 1){
            newUrl = newUrl + "?" + arr[1];
        }
        return newUrl;
    }
}

==> thirdparty-service-biz-0.0.9.3-20171201.122103-1-sources.jar: cn/com/duiba/biz/credits/FengJinApi.java <==
package cn.com.duiba.biz.credits;

import cn.com.duiba.credits.sdk.SignTool;
import cn.com.duiba.dao.AppDAO;
import cn.com.duiba.domain.AppDO;
import cn.com.duiba.notifycenter.domain.NotifyQueueDO;
import cn.com.duiba.order.center.api.dto.CreditsMessage;
import cn.com.duiba.thirdparty.dto.CreditsMessageDto;
import cn.com.duiba.tool.AssembleTool;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.util.Arrays;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Created by xutao on 2017/8/14.
 */
@Service
public class FengJinApi {
    private static Logger log = LoggerFactory.getLogger(FengJinApi.class);

    public static final String UID = "uid";

    @Autowired
    private AppDAO appDAO;

    /**
     * 针对减积分的对象
     * @param creditsMessage
     * @return
     */
    public CreditsMessage getSubCreditsMessage(CreditsMessage creditsMessage) {
        String url = getUrl(creditsMessage.getHttpType(), creditsMessage.getAuthParams(), creditsMessage.getHttpUrl());
        creditsMessage.setHttpUrl(url);
//        log.info("appId = {}, url = {}", creditsMessage.getAppId(), creditsMessage.getHttpUrl());
        return creditsMessage;
    }

    private String getUrl(String httpType, Map<String, String> params, String url) {
        if (CreditsMessage.HTTP_POST.equals(httpType)) {
            if(params != null && StringUtils.isNotBlank(params.get("uid"))){
                url = getFengJinPostUrl(url, params);
            }
        } else {
            url = getFengJinGetUrl(url);
        }
        return url;
    }

    /**
     * 针对加积分的对象
     * @param creditsMessageDto
     * @return
     */
    public CreditsMessageDto getAddCreditsMessageDto(CreditsMessageDto creditsMessageDto) {
        String url = getUrl(creditsMessageDto.getHttpType(), creditsMessageDto.getAuthParams(), creditsMessageDto.getHttpUrl());
        creditsMessageDto.setHttpUrl(url);
//        log.info("appId = {}, url = {}", creditsMessageDto.getAppId(), creditsMessageDto.getHttpUrl());
        return creditsMessageDto;
    }

    /**
     * 凤金积分商城, 获取通知请求参数
     * @param notifyUrl
     * @param record
     * @return
     */
    public String getRequestNotify(String notifyUrl, NotifyQueueDO record, AppDO appDO){
        Map<String, String> params = new HashMap();
        if(record.getResult() != null){
            params.put("success", String.valueOf(record.getResult()));
        }

        if(StringUtils.isNotEmpty(record.getError4developer())) {
            params.put("errorMessage", record.getError4developer());
        }
        if(StringUtils.isNotEmpty(record.getDeveloperBizId())){
            params.put("bizId",record.getDeveloperBizId());
        }
        params.put("appKey", appDO.getAppKey());
        params.put("appSecret", appDAO.getAppSecret(appDO));
        params.put("timestamp", String.valueOf(Long.valueOf(new Date().getTime())));
        if(StringUtils.isNotEmpty(record.getPartnerUserId())){
            params.put("uid", record.getPartnerUserId());
        }

        params.put("orderNum", record.getDuibaOrderNum());
        String sign = SignTool.sign(params);
        params.remove("appSecret");
        params.put("sign", sign);

        if(StringUtils.isNotBlank(record.getPartnerUserId())){
            if(notifyUrl.endsWith("/")){
                notifyUrl = notifyUrl + record.getPartnerUserId();
            }else{
                notifyUrl = notifyUrl + "/" + record.getPartnerUserId();
            }
        }

        return AssembleTool.assembleUrl(notifyUrl, params);
    }

    /**
     * 凤金积分商城 url handler
     * @param url
     * @return
     */
    private String getFengJinGetUrl(String url){
        try{
            String[] arr = url.split("[?]");
            String newUrl = arr[0];
            if(arr.length < 2){
                return newUrl;
            }

            List<String> paramList = Arrays.asList(arr[1].split("[&]"));
            for(String value : paramList){
                if(StringUtils.isNotBlank(value) && value.trim().startsWith("uid=")){
                    String uid = value.replace("uid=", "");
                    if(StringUtils.isBlank(uid)){
                        break;
                    }
                    if(newUrl.endsWith("/")){
                        newUrl = newUrl + URLDecoder.decode(uid, "utf-8");
                    }else{
                        newUrl = newUrl + "/" + URLDecoder.decode(uid, "utf-8");
                    }
                    break;
                }
            }

            newUrl = newUrl + "?" + arr[1];
            return newUrl;
        }catch (UnsupportedEncodingException e){
            log.error("[AssembleTool-getFengJinGetUrl] URL parsing error, url: " + url,e);
            throw new IllegalStateException("URL parsing error when using utf-8");
        }
    }

    /**
     * 凤金积分商城 url handler
     * @param url
     * @param params
     * @return
     */
    private String getFengJinPostUrl(String url, Map<String, String> params){
        String[] arr = url.split("[?]");
        String newUrl = arr[0];
        if(newUrl.endsWith("/")){
            newUrl = newUrl + params.get(UID);
        }else{
            newUrl = newUrl + "/" + params.get(UID);
        }

        if(arr.length > 1){
            newUrl = newUrl + "?" + arr[1];
        }
        return newUrl;
    }
}
